# AMOS

A Portable Package for Bessel Functions of a Complex Argument
and Nonnegative Order

This algorithm is a package of subroutines for computing Bessel
functions and Airy functions.  The routines are updated
versions of those routines found in TOMS algorithm 644.

## Disclaimer

```
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
*                 ISSUED BY SANDIA LABORATORIES,
*                   A PRIME CONTRACTOR TO THE
*               UNITED STATES DEPARTMENT OF ENERGY
* * * * * * * * * * * * * *  NOTICE   * * * * * * * * * * * * * * *
* THIS REPORT WAS PREPARED AS AN ACCOUNT OF WORK SPONSORED BY THE
* UNITED STATES GOVERNMENT.  NEITHER THE UNITED STATES NOR THE
* UNITED STATES DEPARTMENT OF ENERGY, NOR ANY OF THEIR
* EMPLOYEES, NOR ANY OF THEIR CONTRACTORS, SUBCONTRACTORS, OR THEIR
* EMPLOYEES, MAKES ANY WARRANTY, EXPRESS OR IMPLIED, OR ASSUMES ANY
* LEGAL LIABILITY OR RESPONSIBILITY FOR THE ACCURACY, COMPLETENESS
* OR USEFULNESS OF ANY INFORMATION, APPARATUS, PRODUCT OR PROCESS
* DISCLOSED, OR REPRESENTS THAT ITS USE WOULD NOT INFRINGE
* PRIVATELY OWNED RIGHTS.
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
* THIS CODE HAS BEEN APPROVED FOR UNLIMITED RELEASE.
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
```
